pub struct AnonymousSessionBuilder<'a> { /* private fields */ }The “fedora” crate is obsolete. The OpenID-based authentication method for Fedora web services provided by this crate no longer works. There is currently no known replacement.
This type encapsulates the (optional) arguments that are required for building an anonymous session.
Implementations
Sourceimpl<'a> AnonymousSessionBuilder<'a>
impl<'a> AnonymousSessionBuilder<'a>
Sourcepub fn new() -> Self
👎Deprecated since 2.1.2: The “fedora” crate is obsolete.
The OpenID-based authentication method for Fedora web services provided by this crate no longer works.
There is currently no known replacement.
pub fn new() -> Self
The “fedora” crate is obsolete. The OpenID-based authentication method for Fedora web services provided by this crate no longer works. There is currently no known replacement.
This method constructs a new AnonymousSessionBuilder instance.
Sourcepub fn timeout(self, timeout: Duration) -> Self
👎Deprecated since 2.1.2: The “fedora” crate is obsolete.
The OpenID-based authentication method for Fedora web services provided by this crate no longer works.
There is currently no known replacement.
pub fn timeout(self, timeout: Duration) -> Self
The “fedora” crate is obsolete. The OpenID-based authentication method for Fedora web services provided by this crate no longer works. There is currently no known replacement.
Override the default request timeout duration.
Sourcepub fn user_agent(self, user_agent: &'a str) -> Self
👎Deprecated since 2.1.2: The “fedora” crate is obsolete.
The OpenID-based authentication method for Fedora web services provided by this crate no longer works.
There is currently no known replacement.
pub fn user_agent(self, user_agent: &'a str) -> Self
The “fedora” crate is obsolete. The OpenID-based authentication method for Fedora web services provided by this crate no longer works. There is currently no known replacement.
Override the default User-Agent header.
Sourcepub fn build(self) -> Session
👎Deprecated since 2.1.2: The “fedora” crate is obsolete.
The OpenID-based authentication method for Fedora web services provided by this crate no longer works.
There is currently no known replacement.
pub fn build(self) -> Session
The “fedora” crate is obsolete. The OpenID-based authentication method for Fedora web services provided by this crate no longer works. There is currently no known replacement.
This method consumes the AnonymousSessionBuilder and returns a Session with
custom timeout and User-Agent header settings.
Note: This method will panic if the network stack cannot be initialized.