pub struct AnonymousSessionBuilder<'a> { /* private fields */ }
This type encapsulates the (optional) arguments that are required for building an anonymous session.

Implementations

This method constructs a new AnonymousSessionBuilder instance.

Override the default request timeout duration.

Override the default User-Agent header.

This method consumes the AnonymousSessionBuilder and returns a Session with custom timeout and User-Agent header settings.

Note: This method will panic if the network stack cannot be initialized.