Struct fedora::AnonymousSessionBuilder
source · [−]pub struct AnonymousSessionBuilder<'a> { /* private fields */ }Expand description
This type encapsulates the (optional) arguments that are required for building an anonymous session.
Implementations
sourceimpl<'a> AnonymousSessionBuilder<'a>
impl<'a> AnonymousSessionBuilder<'a>
sourcepub fn new() -> Self
pub fn new() -> Self
This method constructs a new AnonymousSessionBuilder instance.
sourcepub fn user_agent(self, user_agent: &'a str) -> Self
pub fn user_agent(self, user_agent: &'a str) -> Self
Override the default User-Agent header.
sourcepub fn build(self) -> Session
pub fn build(self) -> Session
This method consumes the AnonymousSessionBuilder and returns a Session with
custom timeout and User-Agent header settings.
Note: This method will panic if the network stack cannot be initialized.